Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration settings for the I8080 interface.

Implementations

Source

impl Config

pub fn with_clock_mode(self, clock_mode: ClockMode) -> Self

Assign the given value to the clock_mode field.

pub fn clock_mode(&self) -> ClockMode

Specifies the clock mode, including polarity and phase settings.

pub fn with_frequency(self, frequency: Rate) -> Self

Assign the given value to the frequency field.

pub fn frequency(&self) -> Rate

The frequency of the pixel clock.

pub fn with_setup_cycles(self, setup_cycles: usize) -> Self

Assign the given value to the setup_cycles field.

pub fn setup_cycles(&self) -> usize

Setup cycles expected, must be at least 1. (6 bits)

pub fn with_hold_cycles(self, hold_cycles: usize) -> Self

Assign the given value to the hold_cycles field.

pub fn hold_cycles(&self) -> usize

Hold cycles expected, must be at least 1. (13 bits)

pub fn with_cd_idle_edge(self, cd_idle_edge: bool) -> Self

Assign the given value to the cd_idle_edge field.

pub fn cd_idle_edge(&self) -> bool

The default value of LCD_CD.

pub fn with_cd_cmd_edge(self, cd_cmd_edge: bool) -> Self

Assign the given value to the cd_cmd_edge field.

pub fn cd_cmd_edge(&self) -> bool

The value of LCD_CD during CMD phase.

pub fn with_cd_dummy_edge(self, cd_dummy_edge: bool) -> Self

Assign the given value to the cd_dummy_edge field.

pub fn cd_dummy_edge(&self) -> bool

The value of LCD_CD during dummy phase.

pub fn with_cd_data_edge(self, cd_data_edge: bool) -> Self

Assign the given value to the cd_data_edge field.

pub fn cd_data_edge(&self) -> bool

The value of LCD_CD during data phase.

pub fn with_cd_mode(self, cd_mode: DelayMode) -> Self

Assign the given value to the cd_mode field.

pub fn cd_mode(&self) -> DelayMode

The output LCD_CD is delayed by module clock LCD_CLK.

pub fn with_output_bit_mode(self, output_bit_mode: DelayMode) -> Self

Assign the given value to the output_bit_mode field.

pub fn output_bit_mode(&self) -> DelayMode

The output data bits are delayed by module clock LCD_CLK.